# Contributing
## Prerequisites
- Install `python`
- Fork the forecast-weather repo
- Run `git clone https://github.com/{your user-id}/forecast-weather.git`
- In cloned repo, run `make develop`

## Contribute
Feel free to work on your own or existing issues with the project. Please add tests for any new features.

## Finish
When you are satisfied with your changes:
- Run `make build`
- Run `make lint`
- Run `make checks`
- Run `make coverage`

Commit your changes, push to your fork, and open a PR to forecast-weather.